
local DF = _G ["DetailsFramework"]
if (not DF) then
	print ("|cFFFFAA00Please restart your client to finish update some AddOns.|r")
	return
end

local default_config = {
	profile = {
		readycheck = true,
		arena_queue = true,
		group_queue = true,
		pull_timers = true,
	}
}

local options_table = {
	name = "FlashTaskBar",
	type = "group",
	args = {
		ReadyCheck = {
			type = "toggle",
			name = "On Ready Check",
			desc = "Flash the task bar on ready check.",
			order = 1,
			get = function() return FlashTaskBar.db.profile.readycheck end,
			set = function (self, val) 
				FlashTaskBar.db.profile.readycheck = not FlashTaskBar.db.profile.readycheck
			end,
		},
		PvP = {
			type = "toggle",
			name = "On PvP Queues",
			desc = "Flash the task bar on battleground and arena queues.",
			order = 2,
			get = function() return FlashTaskBar.db.profile.arena_queue end,
			set = function (self, val) 
				FlashTaskBar.db.profile.arena_queue = not FlashTaskBar.db.profile.arena_queue
			end,
		},
		RaidFinder = {
			type = "toggle",
			name = "On Finder Queues",
			desc = "Flash the task bar on raid, dungeon finders.",
			order = 3,
			get = function() return FlashTaskBar.db.profile.group_queue end,
			set = function (self, val) 
				FlashTaskBar.db.profile.group_queue = not FlashTaskBar.db.profile.group_queue
			end,
		},
		PullTimers = {
			type = "toggle",
			name = "Pull Timers",
			desc = "When a pull timer starts from BigWigs or DBM.",
			order = 4,
			get = function() return FlashTaskBar.db.profile.pull_timers end,
			set = function (self, val) 
				FlashTaskBar.db.profile.pull_timers = not FlashTaskBar.db.profile.pull_timers
			end,
		},
	}
}

local FlashTaskBar = DF:CreateAddOn ("FlashTaskBar", "FlashTaskbarDB", default_config, options_table)

FlashTaskBar.last_flash = 0

function FlashTaskBar:DoFlash()
	if (FlashTaskBar.last_flash + 5 < GetTime()) then
		FlashClientIcon()
		FlashTaskBar.last_flash = GetTime()
	end
end

function FlashTaskBar.OnInit (self)
	hooksecurefunc ("LFGDungeonReadyStatus_ResetReadyStates", function()
		if (FlashTaskBar.db.profile.group_queue) then
			FlashTaskBar:DoFlash()
		end
	end)
	hooksecurefunc ("PVPReadyDialog_Display", function()
		if (FlashTaskBar.db.profile.arena_queue) then
			FlashTaskBar:DoFlash()
		end
	end)
	
	function FlashTaskBar:CommReceived (_, prefix)
		if (not FlashTaskBar.db.profile.pull_timers) then
			return
		end
		if (prefix:find ("PT")) then
			FlashTaskBar:DoFlash()
		elseif (prefix:find ("BWPull")) then
			FlashTaskBar:DoFlash()
		end
	end
	FlashTaskBar:RegisterComm ("D4", "CommReceived")
	FlashTaskBar:RegisterComm ("BigWigs", "CommReceived")
	
	function FlashTaskBar:READY_CHECK()
		if (FlashTaskBar.db.profile.readycheck) then
			FlashTaskBar:DoFlash()
		end
	end
	FlashTaskBar:RegisterEvent ("READY_CHECK")
end



